@@ -18,13 +18,24 @@ def to_bytes_and_len(value: Optional[str]) -> Tuple[bytes, int]:
     return (value_bytes, value_len)
 
 
-def connect_to_database(connection_string, user, password) -> Any:
+def connect_to_database(
+    connection_string: str,
+    user: Optional[str],
+    password: Optional[str],
+    login_timeout_sec: Optional[int],
+) -> Any:
 
     connection_string_bytes = connection_string.encode("utf-8")
 
     (user_bytes, user_len) = to_bytes_and_len(user)
     (password_bytes, password_len) = to_bytes_and_len(password)
 
+    if login_timeout_sec is None:
+        login_timeout_sec_ptr = FFI.NULL
+    else:
+        login_timeout_sec_ptr = ffi.new("uint32_t *")
+        login_timeout_sec_ptr[0] = login_timeout_sec
+
     connection_out = ffi.new("OdbcConnection **")
 
     # Open connection to ODBC Data Source
@@ -35,6 +46,7 @@ def connect_to_database(connection_string, user, password) -> Any:
         user_len,
         password_bytes,
         password_len,
+        login_timeout_sec_ptr,
         connection_out,
     )
     # See if we connected successfully and return an error if not
